@@ -712,12 +712,14 @@ g_main_iterate (gboolean block,
 
   G_LOCK (main_loop);
 
+#ifdef G_THREADS_ENABLED
   if (poll_waiting)
     {
       g_warning("g_main_iterate(): main loop already active in another thread");
       G_UNLOCK (main_loop);
       return FALSE;
     }
+#endif G_THREADS_ENABLED  
   
   /* If recursing, finish up current dispatch, before starting over */
   if (pending_dispatches)
@@ -996,7 +998,12 @@ g_main_poll (gint     timeout,
       if (pollrec->fd->events)
 	{
 	  fd_array[i].fd = pollrec->fd->fd;
-	  fd_array[i].events = pollrec->fd->events;
+	  /* In direct contradiction to the Unix98 spec, IRIX runs into
+	   * difficulty if you pass in POLLERR, POLLHUP or POLLNVAL
+	   * flags in the events field of the pollfd while it should
+	   * just ignoring them. So we mask them out here.
+	   */
+	  fd_array[i].events = pollrec->fd->events & ~(G_IO_ERR|G_IO_HUP|G_IO_NVAL);
 	  fd_array[i].revents = 0;
 	  i++;
 	}
@@ -1072,7 +1079,10 @@ g_main_poll (gint     timeout,
    * and let the main loop rerun
    */
   if (poll_changed)
-    return;
+    {
+      g_free (fd_array);
+      return;
+    }
 #endif
 
   pollrec = poll_records;
